@@ -13,12 +13,11 @@ class Activity:
     """Represents a historical activity for a Litter-Robot."""
 
     timestamp: datetime | date
-    unit_status: LitterBoxStatus = LitterBoxStatus.UNKNOWN
-    count: int = 1
+    action: str | LitterBoxStatus
 
     def __str__(self) -> str:
         """Return self(str)."""
-        return f"{self.timestamp.isoformat()}: {self.unit_status.text} - {pluralize('cycle', self.count)}"
+        return f"{self.timestamp.isoformat()}: {self.action.text if isinstance(self.action, LitterBoxStatus) else self.action}"
 
 
 @dataclass
@@ -27,7 +26,7 @@ class Insight:
 
     total_cycles: int
     average_cycles: float
-    cycle_history: list[Activity]
+    cycle_history: list[tuple[date, int]]
 
     @property
     def total_days(self) -> int:
