@@ -30,18 +30,22 @@ _LOGGER = logging.getLogger(__name__)
 
 LR4_ENDPOINT = "https://lr4.iothings.site/graphql"
 LR4_STATUS_MAP = {
+    "ROBOT_BONNET": LitterBoxStatus.BONNET_REMOVED,
     "ROBOT_CAT_DETECT": LitterBoxStatus.CAT_DETECTED,
     "ROBOT_CAT_DETECT_DELAY": LitterBoxStatus.CAT_SENSOR_TIMING,
     "ROBOT_CLEAN": LitterBoxStatus.CLEAN_CYCLE,
-    # "ROBOT_FIND_DUMP": happened during cleaning
+    "ROBOT_EMPTY": LitterBoxStatus.EMPTY_CYCLE,
+    "ROBOT_FIND_DUMP": LitterBoxStatus.DUMP_POSITION_FAULT,
     "ROBOT_IDLE": LitterBoxStatus.READY,
     "ROBOT_POWER_DOWN": LitterBoxStatus.POWER_DOWN,
     "ROBOT_POWER_OFF": LitterBoxStatus.OFF,
     "ROBOT_POWER_UP": LitterBoxStatus.POWER_UP,
 }
 ACTIVITY_STATUS_MAP: dict[str, LitterBoxStatus | str] = {
+    "bonnetRemovedYes": LitterBoxStatus.BONNET_REMOVED,
     "catDetectStuckLaser": LitterBoxStatus.CAT_SENSOR_FAULT,
     "catWeight": "Pet Weight Recorded",
+    "DFIFullFlagOn": LitterBoxStatus.DRAWER_FULL,
     "powerTypeDC": "Battery Backup",
     "robotCycleStateCatDetect": LitterBoxStatus.CAT_SENSOR_INTERRUPTED,
     "robotCycleStatusDump": LitterBoxStatus.CLEAN_CYCLE,
